
# This file was generated by 'versioneer.py' (0.14) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = '0.26.0'
version_full = 'f63f7b0b67bfc159a9cc4e6a9728c67f8c690825'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}

